//******************************************************************************
//  ES449 Jenny Demo
//
//	by
//  SoftBaugh, Inc.
//  January 2003
//  Built with IAR Embedded Workbench Version: 1.26A/WIN
//******************************************************************************

#include "msp430x44x.h"

#define LCD_DIV_32	0x00
#define LCD_DIV_64	0x08
#define LCD_DIV_128	0x10
#define LCD_DIV_256	0x18

void InitializeHardware( void );
void DisplayAccessories( void );

int m_nAccessoryState = 0;

void main( void )
{	
    WDTCTL = WDTPW + WDTHOLD;             // Stop WDT

	InitializeHardware();

	_EINT();    // Enable interrupts

	for (;;)                              
	{
		// Clear P1.6
		P1OUT &= ~(0x40);

	    _BIS_SR(LPM3_bits);                 // Enter LPM3
		_NOP();                             // Required only for C-spy

		// Set P1.6
		P1OUT |= 0x40;

		DisplayAccessories();
	}
}

void DisplayAccessories( void )
{
	switch( m_nAccessoryState )
	{	case 0:
			LCDM1 = 0x2F;	// S1:S0
			LCDM2 = 0x1F;	// S3:S2
			break;

		case 1:
			LCDM1 = 0x2F;	// S1:S0
			LCDM2 = 0x2D;	// S3:S2
			break;

		case 2:
			LCDM1 = 0x0F;	// S1:S0
			LCDM2 = 0x4D;	// S3:S2
			break;

		case 3:
			LCDM1 = 0x0F;	// S1:S0
			LCDM2 = 0x8D;	// S3:S2
			break;

		case 4:
			LCDM1 = 0x2F;	// S1:S0
			LCDM2 = 0x19;	// S3:S2
			break;
	
		case 5:
			LCDM1 = 0x3F;	// S1:S0
			LCDM2 = 0x29;	// S3:S2
			break;

		case 6:
			LCDM1 = 0x2F;	// S1:S0
			LCDM2 = 0x49;	// S3:S2
			break;

		case 7:
			LCDM1 = 0x3F;	// S1:S0
			LCDM2 = 0x81;	// S3:S2
			break;

		case 8:
			LCDM1 = 0xBF;	// S1:S0
			LCDM2 = 0x11;	// S3:S2
			break;

		case 9:
			LCDM1 = 0xFF;	// S1:S0
			LCDM2 = 0x20;	// S3:S2
			break;

		case 10:
			LCDM1 = 0xBF;	// S1:S0
			LCDM2 = 0x40;	// S3:S2
			break;

		case 11:
			LCDM1 = 0xFF;	// S1:S0
			LCDM2 = 0x8F;	// S3:S2
			break;

		default:
			m_nAccessoryState = 0;
	}
	
	m_nAccessoryState++;
	if( m_nAccessoryState >= 12 )
	{	m_nAccessoryState = 0;
	}
}

void InitializeHardware( void )
{
	FLL_CTL0 |= XCAP18PF;       // Set load capacitance for xtal
	
	// Twiddle for fun
	P5DIR |= 0xC0;
	P5OUT |= 0x80;
	P5OUT &= ~(0x80);
	P5OUT |= 0x80;
	P5OUT &= ~(0x80);

	// Setup Basic Timer for LCD operation
	BTCTL = (LCD_DIV_64+0x23);

	// Turn on Basic Timer interrupts
	IE2 |= BTIE;

	// Setup port functions
	P1SEL = 0x32;
	P2SEL = 0x00;
	P3SEL = 0x00;
	P4SEL = 0xFC;
	P5SEL = 0xFF;
	
	// Setup LCD
	LCDCTL = (LCDSG0_7|LCD4MUX|LCDON);
	
	// Setup LCD data
	LCDM1 = 0x0F;	// S1:S0	
	LCDM2 = 0x00;	// S3:S2
	LCDM3 = 0x72;	// S5:S4
	LCDM4 = 0x33;	// S7:S6
	LCDM5 = 0xF7;	// S9:S8
	LCDM6 = 0x07;	// S11:S10
	LCDM7 = 0xE2;	// S13:S12
	LCDM8 = 0xC4;	// S15:S14
	LCDM9 = 0xF0;	// S17:S16
	LCDM10 = 0x60;	// S19:S18
	LCDM11 = 0xF2;	// S21:S20
	LCDM12 = 0x04;	// S23:S22
	LCDM13 = 0xB2;	// S25:S24
	LCDM14 = 0x44;	// S27:S26
	LCDM15 = 0xE0;	// S29:S28
	LCDM16 = 0x00;	// S31:S30
	LCDM17 = 0x32;	// S33:S32
	LCDM18 = 0x64;	// S35:S34
	LCDM19 = 0xF2;	// S37:S36
	LCDM20 = 0xF4;	// S39:S38

	// Clear LED
	P1OUT |= 0x01;
	// Setup Blinky
	P1DIR = 0x73;
}

// Basic Timer interrupt service routine
interrupt[BASICTIMER_VECTOR] void basic_timer(void)
{
	_BIC_SR_IRQ(LPM3_bits);
}



